durationtools.multiply_duration_pair_and_try_to_preserve_numerator
==================================================================

.. autofunction:: abjad.tools.durationtools.multiply_duration_pair_and_try_to_preserve_numerator.multiply_duration_pair_and_try_to_preserve_numerator
